<?php
/**
*
*	Site Analyzer API Client
*	Version 5.1
*	More details on Site-Analyzer.com
*	Copyright Site-Analyzer.com
*	A product of VSI Innovation SAS ©	
*
**/

namespace SiteAnalyzer\Api;

class Client {
	
    /**
     * The client Public Key
     *
     * Get your client public key on Site-Analyzer.com
     *
     * @var string
     */
   	private $client_public = 'YOUR_CLIENT_PUBLIC_KEY_HERE';

    /**
     * The client Public Key
     *
     * Get your client Secret key on Site-Analyzer.com
     * Warning ! Keep this key secret. This is the only place
     * you have to fill your secret key.
     *
     * @var string
     */
	private $client_secret = 'YOUR_CLIENT_SECRET_KEY_HERE';
	
	/** ------- DO NOT EDIT FILE UNDER THIS LINE -------- **/
	
    /**
     * Call signature
     *
     * Signature generated by the Client
     *
     * @var string
     */
	private $signature;

    /**
     * API Version
     *
     * Version of the API you use (not the Client version)
     *
     * @var string
     */
	private $version = '5.1';
	
	/**
     * API Base URL
     *
     * Site Analyzer API Url
     *
     * @var string
     */
	private $base_url = 'https://api.site-analyzer.com/';
	
	/**
     * Action Name
     *
     * Last call action name
     *
     * @var string
     */
	private $action;
	
	
	public function __construct()
	{
	}
	
	/**
	 * Set Client Public Key
	 *
	 * Use this function if you wan't to change your API Keys from outside this class
	 *
	 * @param string $client_public The Client API Public Key
	 *
	 * @return (void)
	 */
	public function set_client_public($client_public)
	{
		$this->client_public = $client_public;
	}
	
	/**
	 * Set Client Secret Key
	 *
	 * Use this function if you wan't to change your API Keys from outside this class
	 *
	 * @param string $client_secret The Client API Secret Key
	 *
	 * @return (void)
	 */
 	public function set_client_secret($client_secret)
	{
		$this->client_secret = $client_secret;
	}
	
	/**
	 * API Call
	 * 
	 * Make an API Call. This is the main function.
	 *
	 * Exemple : 
	 * $response = $Api->call('domaininfo', array('url'=>'domain.com') );
	 *
	 * @param string $action The API feature you wan't to use.
	 * @param array  $params Parameters of the call
	 * @param string $method Method to use (POST, GET, PUT, DELETE, ...)
	 *
	 * @return json Result of the API call
	 */
	public function call($action, $params=array(), $method='POST')
	{
		$this->method = strtoupper($method);
		$this->action = strtolower($action);
		$this->params = $params;
		$this->data_string = http_build_query(array('params'=>$params)).'&action='.$this->action;

		$url = $this->base_url.$this->version."/".$this->action;

		return $this->curl($url);

	}
	
	/**
	 * Curl
	 * 
	 * Connection to the API, Authentification and call.
	 *
	 * @param string $url Url to connect to
	 *
	 * @return JSON;
	 */
	private function curl($url)
	{
		$ch = curl_init($url);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		//curl_setopt($ch, CURLOPT_TIMEOUT, 1);
		curl_setopt($ch, CURLOPT_HEADER, 0);
        if($this->method == 'POST')
			curl_setopt($ch, CURLOPT_POST, 1);
        elseif($this->method != 'GET')
            curl_setopt($ch, CURLOPT_CUSTOMREQUEST, $this->method);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $this->data_string);
		curl_setopt($ch, CURLOPT_AUTOREFERER, true);
		curl_setopt($ch, CURLOPT_REFERER, $_SERVER['HTTP_HOST']);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'x-api-public: '.$this->client_public,
            'x-api-signature: '.$this->signature()
        ));
		$response = curl_exec($ch); 
	
		return $response;
		
		curl_close($ch);
	}
	
	
	/**
	 * Generate Signature
	 * 
	 * Generate signature to send to the Server in order to Authentificaiton
	 *
	 * @return string Client Signature;
	 */
	private function signature()
	{
		$data = $this->version.$this->action.http_build_query($this->params).$this->client_secret.$this->client_public;
		return hash('sha256',$data);
	}
	
}
		
?>
